@@ -32,6 +32,7 @@ use ast_grep_core::language::{TSLanguage, TSRange};
 use ast_grep_core::meta_var::MetaVariable;
 use ast_grep_core::{Doc, Node};
 use ignore::types::{Types, TypesBuilder};
+use serde::de::Visitor;
 use serde::{de, Deserialize, Deserializer, Serialize};
 use std::borrow::Cow;
 use std::collections::HashMap;
@@ -46,7 +47,7 @@ pub use ast_grep_core::Language;
 /// this macro implements bare-bone methods for a language
 macro_rules! impl_lang {
   ($lang: ident, $func: ident) => {
-    #[derive(Clone, Copy)]
+    #[derive(Clone, Copy, Debug)]
     pub struct $lang;
     impl Language for $lang {
       fn get_ts_language(&self) -> TSLanguage {
@@ -81,7 +82,7 @@ fn pre_process_pattern(expando: char, query: &str) -> std::borrow::Cow<str> {
 /// use this if your language does not accept $ as valid identifier char
 macro_rules! impl_lang_expando {
   ($lang: ident, $func: ident, $char: expr) => {
-    #[derive(Clone, Copy)]
+    #[derive(Clone, Copy, Debug)]
     pub struct $lang;
     impl ast_grep_core::language::Language for $lang {
       fn get_ts_language(&self) -> ast_grep_core::language::TSLanguage {
@@ -97,6 +98,53 @@ macro_rules! impl_lang_expando {
   };
 }
 
+/// Implements the `ALIAS` associated constant for the given lang, which is
+/// then used to define the `alias` const fn and a `Deserialize` impl.
+macro_rules! impl_alias {
+  ($lang:ident => $as:expr) => {
+    impl $lang {
+      pub const ALIAS: &'static [&'static str] = $as;
+    }
+
+    impl fmt::Display for $lang {
+      fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        write!(f, "{:?}", self)
+      }
+    }
+
+    impl<'de> Deserialize<'de> for $lang {
+      fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
+      where
+        D: Deserializer<'de>,
+      {
+        let vis = AliasVisitor {
+          aliases: Self::ALIAS,
+        };
+        deserializer.deserialize_str(vis)?;
+        Ok($lang)
+      }
+    }
+
+    impl From<$lang> for SupportLang {
+      fn from(_: $lang) -> Self {
+        Self::$lang
+      }
+    }
+  };
+}
+/// Generates as convenience conversions between the lang types
+/// and `SupportedType`.
+macro_rules! impl_aliases {
+  ($($lang:ident => $as:expr),* $(,)?) => {
+    $(impl_alias!($lang => $as);)*
+    const fn alias(lang: SupportLang) -> &'static [&'static str] {
+      match lang {
+        $(SupportLang::$lang => $lang::ALIAS),*
+      }
+    }
+  };
+}
+
 /* Customized Language with expando_char / pre_process_pattern */
 // https://en.cppreference.com/w/cpp/language/identifiers
 // Due to some issues in the tree-sitter parser, it is not possible to use
@@ -187,12 +235,12 @@ impl SupportLang {
   }
 
   pub fn file_types(&self) -> Types {
-    file_types(self)
+    file_types(*self)
   }
 }
 
 impl fmt::Display for SupportLang {
-  fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+  fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
     write!(f, "{:?}", self)
   }
 }
@@ -218,49 +266,85 @@ impl<'de> Deserialize<'de> for SupportLang {
   where
     D: Deserializer<'de>,
   {
-    let s = String::deserialize(deserializer)?;
-    FromStr::from_str(&s).map_err(de::Error::custom)
+    deserializer.deserialize_str(SupportLangVisitor)
   }
 }
 
-const fn alias(lang: &SupportLang) -> &[&str] {
-  use SupportLang::*;
-  match lang {
-    Bash => &["bash-exp"],
-    C => &["c"],
-    Cpp => &["cc", "c++", "cpp", "cxx"],
-    CSharp => &["cs", "csharp"],
-    Css => &["css"],
-    Dart => &["dart"],
-    Elixir => &["ex", "elixir"],
-    Go => &["go", "golang"],
-    Haskell => &["hs", "haskell"],
-    Html => &["html"],
-    Java => &["java"],
-    JavaScript => &["javascript", "js", "jsx"],
-    Json => &["json"],
-    Kotlin => &["kotlin", "kt"],
-    Lua => &["lua"],
-    Php => &["php-exp"],
-    Python => &["py", "python"],
-    Ruby => &["rb", "ruby"],
-    Rust => &["rs", "rust"],
-    Scala => &["scala"],
-    Sql => &["sql"],
-    Swift => &["swift"],
-    TypeScript => &["ts", "typescript"],
-    Tsx => &["tsx"],
+struct SupportLangVisitor;
+
+impl<'de> Visitor<'de> for SupportLangVisitor {
+  type Value = SupportLang;
+
+  fn expecting(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    f.write_str("SupportLang")
   }
+
+  fn visit_str<E>(self, v: &str) -> Result<Self::Value, E>
+  where
+    E: de::Error,
+  {
+    v.parse().map_err(de::Error::custom)
+  }
+}
+struct AliasVisitor {
+  aliases: &'static [&'static str],
+}
+
+impl<'de> Visitor<'de> for AliasVisitor {
+  type Value = &'static str;
+
+  fn expecting(&self, f: &mut fmt::Formatter) -> fmt::Result {
+    write!(f, "one of {:?}", self.aliases)
+  }
+
+  fn visit_str<E>(self, v: &str) -> Result<Self::Value, E>
+  where
+    E: de::Error,
+  {
+    self
+      .aliases
+      .iter()
+      .copied()
+      .find(|&a| v.eq_ignore_ascii_case(a))
+      .ok_or_else(|| de::Error::invalid_value(de::Unexpected::Str(v), &self))
+  }
+}
+
+impl_aliases! {
+  Bash => &["bash"],
+  C => &["c"],
+  Cpp => &["cc", "c++", "cpp", "cxx"],
+  CSharp => &["cs", "csharp"],
+  Css => &["css"],
+  Dart => &["dart"],
+  Elixir => &["ex", "elixir"],
+  Go => &["go", "golang"],
+  Haskell => &["hs", "haskell"],
+  Html => &["html"],
+  Java => &["java"],
+  JavaScript => &["javascript", "js", "jsx"],
+  Json => &["json"],
+  Kotlin => &["kotlin", "kt"],
+  Lua => &["lua"],
+  Php => &["php"],
+  Python => &["py", "python"],
+  Ruby => &["rb", "ruby"],
+  Rust => &["rs", "rust"],
+  Scala => &["scala"],
+  Sql => &["sql"],
+  Swift => &["swift"],
+  TypeScript => &["ts", "typescript"],
+  Tsx => &["tsx"],
 }
 
 /// Implements the language names and aliases.
 impl FromStr for SupportLang {
   type Err = SupportLangErr;
   fn from_str(s: &str) -> Result<Self, Self::Err> {
-    for lang in Self::all_langs() {
+    for &lang in Self::all_langs() {
       for moniker in alias(lang) {
         if s.eq_ignore_ascii_case(moniker) {
-          return Ok(*lang);
+          return Ok(lang);
         }
       }
     }
@@ -332,7 +416,7 @@ impl Language for SupportLang {
   }
 }
 
-fn extensions(lang: &SupportLang) -> &[&str] {
+fn extensions(lang: SupportLang) -> &'static [&'static str] {
   use SupportLang::*;
   match lang {
     Bash => &[
@@ -372,7 +456,7 @@ fn from_extension(path: &Path) -> Option<SupportLang> {
   SupportLang::all_langs()
     .iter()
     .copied()
-    .find(|l| extensions(l).contains(&ext))
+    .find(|&l| extensions(l).contains(&ext))
 }
 
 fn add_custom_file_type<'b>(
@@ -389,7 +473,7 @@ fn add_custom_file_type<'b>(
   builder.select(file_type)
 }
 
-fn file_types(lang: &SupportLang) -> Types {
+fn file_types(lang: SupportLang) -> Types {
   let mut builder = TypesBuilder::new();
   let exts = extensions(lang);
   let lang_name = lang.to_string();
@@ -427,6 +511,7 @@ mod test {
       cand.root().to_sexp(),
     );
   }
+
   pub fn test_replace_lang(
     src: &str,
     pattern: &str,
